@@ -151,7 +151,8 @@ class MCPAgent:
         defaults = {
             "anthropic": "claude-sonnet-4-20250514",
             "openai": "gpt-4o",
-            "gemini": "gemini-2.5-pro"
+            "gemini": "gemini-2.5-pro",
+            "groq": "moonshotai/kimi-k2-instruct"
         }
         return defaults.get(self.provider_name, "default")
     
