@@ -2,12 +2,14 @@ from .base import LLMProvider
 from .anthropic_provider import AnthropicProvider
 from .openai_provider import OpenAIProvider
 from .gemini_provider import GeminiProvider
+from .groq_provider import GroqProvider
 
 # Provider registry for easy access
 PROVIDERS = {
     "anthropic": AnthropicProvider,
     "openai": OpenAIProvider,
     "gemini": GeminiProvider,
+    "groq": GroqProvider,
 }
 
-__all__ = ["LLMProvider", "AnthropicProvider", "OpenAIProvider", "GeminiProvider", "PROVIDERS"]
\ No newline at end of file
+__all__ = ["LLMProvider", "AnthropicProvider", "OpenAIProvider", "GeminiProvider", "GroqProvider", "PROVIDERS"]
\ No newline at end of file
